@@ -2,9 +2,9 @@
 /**
  * Change LDAP Password plugin functions
  * @copyright &copy; 2000-2003 Simon Annetts <simon@ateb.co.uk>
- * @copyright &copy; 2006 The SquirrelMail Project Team
+ * @copyright &copy; 2006-2007 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: functions.php,v 1.6 2006/10/07 06:32:01 tokul Exp $
+ * @version $Id: functions.php,v 1.7 2007/01/20 11:51:22 tokul Exp $
  * @package plugins
  * @subpackage change_ldappass
  */
@@ -69,6 +69,7 @@ function change_ldappass_go($cp_oldpass, $cp_newpass) {
     $ldap_user_field = 'uid';
     $query_dn = '';
     $query_pw = '';
+    $ldap_filter = '';
 
     $no_bind_as_user = false;
 
@@ -139,8 +140,14 @@ function change_ldappass_go($cp_oldpass, $cp_newpass) {
         }
     }
 
+    if (!empty($ldap_filter)) {
+        $filter = "(&($ldap_filter)($ldap_user_field=$username))";
+    } else {
+        $filter = "($ldap_user_field=$username)";
+    }
+
     // Hide ldap_search notices
-    $sr=@ldap_search($ds,$ldap_base_dn,"($ldap_user_field=$username)",array('dn')); //search for uid
+    $sr=@ldap_search($ds,$ldap_base_dn,$filter,array('dn')); //search for uid
     if (! $sr) {
         array_push($Messages, _("LDAP search failed."),
                    sprintf(_("Error: %s"),htmlspecialchars(ldap_err2str(ldap_errno($ds)))));
