@@ -20,9 +20,9 @@
  * change_ldappass v.2.0 version is relicensed under GPL.
  *
  * @copyright &copy; 2000-2003 Simon Annetts <simon@ateb.co.uk>
- * @copyright &copy; 2006 The SquirrelMail Project Team
+ * @copyright &copy; 2006-2007 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: options.php,v 1.9 2006/10/06 20:24:32 tokul Exp $
+ * @version $Id: options.php,v 1.10 2007/01/20 11:51:22 tokul Exp $
  * @package plugins
  * @subpackage change_ldappass
  */
@@ -44,7 +44,7 @@ if ( file_exists(SM_PATH . 'plugins/change_ldappass/config.php') &&
     textdomain('squirrelmail');
 }
 
-displayPageHeader($color, "None");
+displayPageHeader($color, '');
 
 bindtextdomain('change_ldappass', SM_PATH . 'plugins/change_ldappass/locale');
 textdomain('change_ldappass');
